Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: source/i18n/unicode/tznames.h

Issue 845603002: Update ICU to 54.1 step 1 (Closed) Base URL: https://chromium.googlesource.com/chromium/deps/icu.git@master
Patch Set: remove unusued directories Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « source/i18n/unicode/tzfmt.h ('k') | source/i18n/unicode/ucal.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: source/i18n/unicode/tznames.h
diff --git a/source/i18n/unicode/tznames.h b/source/i18n/unicode/tznames.h
index 78669d466b4eb41f2e0cef3fb8cc17ebbbc5c4cb..9583ded022f2eb2b8104b1255a02d1657e7e7812 100644
--- a/source/i18n/unicode/tznames.h
+++ b/source/i18n/unicode/tznames.h
@@ -1,7 +1,7 @@
/*
*******************************************************************************
-* Copyright (C) 2011-2013, International Business Machines Corporation and *
-* others. All Rights Reserved. *
+* Copyright (C) 2011-2014, International Business Machines Corporation and
+* others. All Rights Reserved.
*******************************************************************************
*/
#ifndef __TZNAMES_H
@@ -60,13 +60,11 @@ typedef enum UTimeZoneNameType {
* @stable ICU 50
*/
UTZNM_SHORT_DAYLIGHT = 0x20,
-#ifndef U_HIDE_DRAFT_API
/**
* Exemplar location name, such as "Los Angeles".
- * @draft ICU 51
+ * @stable ICU 51
*/
UTZNM_EXEMPLAR_LOCATION = 0x40
-#endif /* U_HIDE_DRAFT_API */
} UTimeZoneNameType;
U_CDECL_END
@@ -160,18 +158,32 @@ public:
virtual TimeZoneNames* clone() const = 0;
/**
* Returns an instance of <code>TimeZoneDisplayNames</code> for the specified locale.
*
* @param locale The locale.
* @param status Recevies the status.
* @return An instance of <code>TimeZoneDisplayNames</code>
* @stable ICU 50
*/
static TimeZoneNames* U_EXPORT2 createInstance(const Locale& locale, UErrorCode& status);
+#ifndef U_HIDE_DRAFT_API
+ /**
+ * Returns an instance of <code>TimeZoneNames</code> containing only short specific
+ * zone names (SHORT_STANDARD and SHORT_DAYLIGHT),
+ * compatible with the IANA tz database's zone abbreviations (not localized).
+ * <br>
+ * Note: The input locale is used for resolving ambiguous names (e.g. "IST" is parsed
+ * as Israel Standard Time for Israel, while it is parsed as India Standard Time for
+ * all other regions). The zone names returned by this instance are not localized.
+ * @draft ICU 54
+ */
+ static TimeZoneNames* U_EXPORT2 createTZDBInstance(const Locale& locale, UErrorCode& status);
+#endif /* U_HIDE_DRAFT_API */
+
/**
* Returns an enumeration of all available meta zone IDs.
- * @param status Recevies the status.
+ * @param status Receives the status.
* @return an enumeration object, owned by the caller.
* @stable ICU 50
*/
@@ -180,7 +192,7 @@ public:
/**
* Returns an enumeration of all available meta zone IDs used by the given time zone.
* @param tzID The canoical tiem zone ID.
- * @param status Recevies the status.
+ * @param status Receives the status.
* @return an enumeration object, owned by the caller.
* @stable ICU 50
*/
@@ -160,18 +158,32 @@ public:
virtual TimeZoneNames* clone() const = 0;
/**
- * Returns an instance of <code>TimeZoneDisplayNames</code> for the specified locale.
+ * Returns an instance of <code>TimeZoneNames</code> for the specified locale.
*
* @param locale The locale.
@@ -160,18 +158,32 @@ public:
*
* @param locale The locale.
- * @param status Recevies the status.
- * @return An instance of <code>TimeZoneDisplayNames</code>
+ * @param status Receives the status.
+ * @return An instance of <code>TimeZoneNames</code>
* @stable ICU 50
*/
« no previous file with comments | « source/i18n/unicode/tzfmt.h ('k') | source/i18n/unicode/ucal.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698